package de.unibi.citec.clf.bonsai.actuators;

/*
 * #LICENSE%
 * BonSAI [Core|Base]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import java.io.IOException;

import de.unibi.citec.clf.bonsai.actuators.data.CameraPosition;
import de.unibi.citec.clf.bonsai.core.Actuator;
import de.unibi.citec.clf.bonsai.core.CommunicationException;

/**
 * Old interface to control a pan-tilt camera.
 * 
 * @author jwienke
 */
public interface OldCameraActuator extends Actuator {

    /**
     * Set the position of the Camera.
     * 
     * @param pan
     *            angle in radiant (0=forward, angles CCW)
     * @param tilt
     *            angle in radiant (0=forward, negative = down)
     * @throws IOException
     */
    void setPos(double pan, double tilt) throws IOException;

    /**
     * set the Zoom of the Camera.
     * 
     * @param zoom
     *            of the camera between 0 and 1 (0=wide, 1=tele)
     * @throws IOException
     */
    void setZoom(double zoom) throws IOException;

    /**
     * set the speed of pan movements.
     * 
     * @param panspeed
     *            of the cameras pan movement
     * @throws IOException
     */
    void setPanSpeed(double panspeed) throws IOException;

    /**
     * set the speed of tilt movements.
     * 
     * @param tiltspeed
     *            of the cameras tilt movement
     * @throws IOException
     */
    void setTiltSpeed(double tiltspeed) throws IOException;

    /**
     * set the zoom speed.
     * 
     * @param zoomspeed
     *            speed
     * @throws IOException
     */
    void setZoomSpeed(double zoomspeed) throws IOException;

    /**
     * Get the current zoom of the camera.
     * 
     * @return [0..1] 0 = wide, 1 = tele
     * @throws IOException
     *             communication error
     */
    float getZoomPos() throws IOException;

    CameraPosition getCameraPosition() throws IOException,
            CommunicationException;

}
