package de.unibi.citec.clf.bonsai.actuators;

/*
 * #LICENSE%
 * BonSAI [Core|Base]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import java.io.IOException;
import java.util.Set;

import de.unibi.citec.clf.bonsai.core.Actuator;

/**
 * Actuator interface to control a visualization of the current system state.
 * 
 * @author jwienke
 */
public interface StateVisualizerActuator extends Actuator {

    /**
     * Configures the visualizer. This must be done before notifying state
     * changes. A second call to this method simply overrides the old
     * configuration.
     * 
     * @param systemName
     *            a descriptive name of the system who's states are shown
     * @param states
     *            a complete list of all possible system states.
     * @throws IOException
     *             communication error
     */
    void configure(String systemName, Set<String> states) throws IOException;

    /**
     * Notifies that the system is in a new state.
     * 
     * @param state
     *            name of the new state. Must have been configured with
     *            {@link #configure(String, Set)} before.
     * @throws IOException
     *             communication error
     */
    void setState(String state) throws IOException;

}
