package de.unibi.citec.clf.bonsai.sensors;

/*
 * #LICENSE%
 * BonSAI [Core|Base]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import de.unibi.citec.clf.bonsai.core.Sensor;
import de.unibi.airobots.btl.data.person.FaceIdentificationList;
import java.io.IOException;

/**
 * An interface for sensors returning face identification results. Moreover
 * learning new persons can be triggered with this interface.
 * 
 * Returning the identification results may be costly so that it can be enabled
 * via {@link #activate()} or disabled with {@link #deactivate()}. Learning is
 * only enabled if the system was activated before via {@link #activate()}.
 * 
 * @author jwienke
 */
public interface FaceIdentificationSensor extends
        Sensor<FaceIdentificationList> {

    /**
     * Activates the identification mechanism. This should only be done if
     * necessary because the computational costs are high.
     * 
     * @throws IOException
     *             communication error
     */
    void activate() throws IOException;

    /**
     * Activates the identification mechanism. This should only be done if
     * necessary because the computational costs are high.
     * 
     * @throws IOException
     *             communication error
     */
    void deactivate() throws IOException;

    /**
     * Enables the cropping of the left of the two faces with highest
     * reliability.
     * 
     * @throws IOException
     *             communication error
     */
    void twoFaces() throws IOException;
    
    
    /**
     * Starts learning the person in front of the camera with a user supplied
     * id. Learning can be stopped with {@link #stopLearning()}. While learning
     * {@link #readLast()} will (after some time) return the supplied id.
     * 
     * @param id
     *            the id of the person to learn
     * @throws IOException
     *             communication error
     */
    void startLearning(int id) throws IOException;

    /**
     * Stops learning the last supplied id.
     * 
     * @throws IOException
     *             communication error
     */
    void stopLearning() throws IOException;
    
    /**
     * Reset.
     * 
     * @throws IOException
     *             communication error
     */
    void reset() throws IOException;

}
