package de.unibi.citec.clf.bonsai.sensors.data;

/*
 * #LICENSE%
 * BonSAI [Core|Base]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.person.PersonData;
import java.util.HashMap;
import java.util.Iterator;
import java.util.LinkedHashMap;

/**
 * Domain class holding Person objects.
 * 
 * @author lschilli
 */
public class PersonList extends Type implements Iterable<PersonData>  {

    private HashMap<Integer, PersonData> personmap =
            new LinkedHashMap<Integer, PersonData>();

    /**
     * Adds a person to this list.
     * 
     * @param p
     *            new person to add
     */
    public void addPerson(PersonData p) {
        personmap.put(p.getId(), p);
    }

    /**
     * Returns the person with the given id in this list or <code>null</code> if
     * not contained.
     * 
     * @param id
     *            id to search for
     * @return person or <code>null</code> if not found
     */
    public PersonData getPersonById(int id) {
        return personmap.get(id);
    }

    @Override
    public Iterator<PersonData> iterator() {
        return personmap.values().iterator();
    }

    /**
     * Returns the number of contained persons.
     * 
     * @return number >= 0
     */
    public int size() {
        return personmap.size();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String toString() {
        return personmap.values().toString();
    }
    
    /**
     * Gives the first Element of the Array behind the Collection.
     * @return null if empty
     */
    public PersonData getFirst() {
        if(personmap != null && !personmap.isEmpty())
            return (PersonData) personmap.values().toArray()[0];
        else
            return null;
    }

}
