package de.unibi.citec.clf.bonsai.util;

/*
 * #LICENSE%
 * BonSAI [Core|Base]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import java.nio.ByteBuffer;

/**
 * For conversion of (binary) data from one format to another.
 * 
 * @author lziegler
 */
public class DataConverter {

    /**
     * Converts an array of float into a byte array.
     * 
     * @param floatData
     *            The floats to convert.
     * @return An array of byte.
     */
    public static byte[] toByteArray(float[] floatData) {

        ByteBuffer bb = ByteBuffer.allocate(4 * floatData.length);
        for (int i = 0; i < floatData.length; i++) {
            bb.putFloat(floatData[i]);
        }
        byte[] byteArray = bb.array();
        return byteArray;
    }

    /**
     * Converts a single float into a byte array.
     * 
     * @param floatData
     *            The float to convert.
     * @return An array of byte.
     */
    public static byte[] toByteArray(float floatData) {

        ByteBuffer bb = ByteBuffer.allocate(4);
        bb.putFloat(floatData);
        byte[] byteArray = bb.array();
        return byteArray;
    }

    /**
     * Converts an array of byte into a float array.
     * 
     * @param byteData
     *            The bytes to convert.
     * @return An array of float.
     */
    public static float[] toFloatArray(byte[] byteData) {

        ByteBuffer bb = ByteBuffer.wrap(byteData);
        float[] floatData = new float[byteData.length / 4];
        int i = 0;
        while (bb.hasRemaining()) {
            float value = bb.getFloat();
            floatData[i++] = value;
        }
        return floatData;
    }
}
