/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Robin Schiewer, Sebastian 
 * Meyer zu Borgsen, Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Tristan 
 * Walter, Viktor Losing, Viktor Richter
 */
package de.unibi.citec.clf.bonsai.xcf;

/*
 * #LICENSE%
 * BonSAI [Core|XCF]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;

import org.apache.log4j.Logger;

import net.sf.xcf.transport.XOPData;
import nu.xom.Document;
import de.unibi.airobots.btl.Type;
import de.unibi.citec.clf.bonsai.core.CommunicationException;
import de.unibi.citec.clf.bonsai.xcf.util.XPathUtilities;

public class AmBtlMemorySlot implements AmWorkingMemorySlot<Type> {
	
	private Logger logger = Logger.getLogger(getClass());

	private AmWorkingMemory memory;
	private Class<? extends Type> dataType;
	private String slot;
	private String baseTag;

	private Method fromDocumentMethod = null;
	private Method getBaseTagMethod = null;

	public AmBtlMemorySlot() {
	}
	
	@Override
	public void initialize(AmWorkingMemory memory, String slot,
			Class<? extends Type> dataType) {
		this.memory = memory;
		this.slot = slot;
		this.dataType = dataType;

		getMethods(dataType);
		baseTag = getBaseTag();
	}

	@Override
	public void memorize(Type object) throws CommunicationException {
		logger.trace("Memorizing");
		XOPData xopData;
		Document rawDoc = object.toDocument(dataType);
		xopData = new XOPData(XPathUtilities.addParentXPath(rawDoc, slot));
		logger.trace("XOP: " + xopData.getDocumentAsText());
		memory.memorize(xopData);
	}

	@Override
	public void forget() throws CommunicationException {
		memory.forget(slot);
	}

	@Override
	public Type recall() throws CommunicationException {

		logger.trace("Recalling");
		XOPData data = memory.recall(slot + "/" + baseTag);

		if (data != null) {
			logger.trace("XOP: " + data.getDocumentAsText());
			Document doc = data.getDocument();
			if (doc == null) {
				throw new CommunicationException("Document empty in XOPData: "
						+ data);
			}

			doc = XPathUtilities.removeParentXPath(doc, slot);

			// create BTL type
			Type obj = safeExtractType(doc);

			return obj;
		} else {
			logger.debug("XOP: null");
			return null;
		}
	}

	@Override
	@SuppressWarnings("unchecked")
	public Class<? extends Type> getDataType() {
		return dataType;
	}

	private void getMethods(Class<? extends Type> dataType) {

		// find fromDocument method for the btl type
		try {
			fromDocumentMethod = dataType.getMethod("fromDocument",
					new Class[] { Document.class, Class.class });
		} catch (SecurityException e) {
			throw new IllegalArgumentException(
					"Error finding a 'fromDocument' method in the given type "
							+ dataType + ".", e);
		} catch (NoSuchMethodException e) {
			throw new IllegalArgumentException(
					"Error finding a 'fromDocument' method in the given type "
							+ dataType + ".", e);
		}

		// find getBaseTag method for the btl type
		try {
			getBaseTagMethod = dataType.getMethod("getBaseTag", new Class[] {});
		} catch (SecurityException e) {
			throw new IllegalArgumentException(
					"Error finding a 'getBaseTag' method in the given type "
							+ dataType + ".", e);
		} catch (NoSuchMethodException e) {
			throw new IllegalArgumentException(
					"Error finding a 'getBaseTag' method in the given type "
							+ dataType + ".", e);
		}
	}

	private String getBaseTag() {
		Object rawResult;
		try {
			rawResult = getBaseTagMethod.invoke(null);
			if (rawResult == null) {
				throw new IllegalArgumentException(
						"getBaseTag method has wrong signature "
								+ "or simply returned null.");
			}
		} catch (IllegalArgumentException e1) {
			throw new IllegalArgumentException(
					"getBaseTag method has wrong signature.", e1);
		} catch (IllegalAccessException e1) {
			throw new IllegalArgumentException(
					"getBaseTag can not be accessed.", e1);
		} catch (InvocationTargetException e1) {
			throw new IllegalArgumentException(
					"getBaseTag throws an exception.", e1);
		}

		return (String) rawResult;
	}

	/**
	 * Safely extracts the BTL type from the document found in the
	 * {@link XOPData}.
	 * 
	 * @param data
	 *            data containing the document
	 * @return extracted BTL type
	 * @throws IOException
	 *             error extracting BTL type instance
	 */
	private Type safeExtractType(Document doc) throws CommunicationException {

		try {
			Object rawResult = fromDocumentMethod.invoke(null, doc, dataType);
			if (rawResult == null) {
				throw new CommunicationException(
						"fromDocument method has wrong signature "
								+ "or simply returned null.");
			}
			return (Type) rawResult;
		} catch (IllegalArgumentException e) {
			throw new CommunicationException(e);
		} catch (IllegalAccessException e) {
			throw new CommunicationException(e);
		} catch (InvocationTargetException e) {
			throw new CommunicationException("Error parsing the document.", e);
		} catch (ExceptionInInitializerError e) {
			throw new CommunicationException(e);
		}
	}
}
