package de.unibi.citec.clf.bonsai.xcf.configuration;

/*
 * #LICENSE%
 * BonSAI [Core|XCF]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import de.unibi.citec.clf.bonsai.core.CoreObjectFactory.SensorToConfigure;
import de.unibi.citec.clf.bonsai.core.Sensor;
import de.unibi.citec.clf.bonsai.xcf.sensors.XcfBtlPublisherSensor;
import de.unibi.airobots.btl.List;
import de.unibi.airobots.btl.Type;

/**
 * Configuration for {@link XcfBtlPublisherSensor}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@link ConfiguredXcfSensor#OPTION_PUBLISHER_NAME} (required): name of the
 * publisher to register on</li>
 * </ul>
 * 
 * @author jwienke
 * @param <T>
 *            sensor data type
 */
public class ConfiguredXcfBtlPublisherSensor<T extends Type> extends
		ConfiguredXcfSensorListable<List<T>, T> {
	
	/**
	 * This method is a helper method to create {@link Class} objects for the
	 * generic {@link List} type.
	 * 
	 * @param type The type of the {@link List}'s elements.
	 * @return A {@link Class} object representing the generic {@link List}.
	 */
	@SuppressWarnings("unchecked")
	public static <T extends Type> Class<List<T>> createListClassOfType(
			Class<T> type) {
		return (Class<List<T>>) new List<T>(type).getClass();
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Sensor<T> createInstance() {
		return new XcfBtlPublisherSensor<T>(getDataType(), getPublisherName());
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public Sensor<List<T>> createInstanceListable() {
		return new XcfBtlPublisherSensor<List<T>>(
				createListClassOfType(getDataType()), getPublisherName());
	}

	/**
	 * Checks if the sensor that can be produced is suitable for the requested
	 * configuration.
	 * 
	 * @param sensor
	 *            requested configuration
	 * @return <code>true</code> if suitable
	 */
	public static boolean isSuitableFor(SensorToConfigure sensor) {
		return sensor.getSensorClass().equals(XcfBtlPublisherSensor.class)
				&& Type.class.isAssignableFrom(sensor.getDataTypeClass());
	}

}
