package de.unibi.citec.clf.bonsai.xcf;

/*
 * #LICENSE%
 * BonSAI [Core|XCF]
 * ---
 * Copyright (C) 2009 - 2013 Frederic Siepmann
 * ---
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 * 
 * http://opensource.cit-ec.de/projects/bonsai
 * 
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 * 
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 * 
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 * 
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 * 
 * Contributors: Florian Lier, Frederic Siepmann, Leon Ziegler, Matthias 
 * Schoepfer, Adriana-Victoria Dreyer, Agnes Swadzba, Andreas Kipp, Birte 
 * Carlmeyer, Christian Ascheberg, Daniel Nacke, Dennis Wigand, Günes Minareci, 
 * Hendrik ter Horst, Ingo Killmann, Jan Pöppel, Lukas Kettenbach, Michael 
 * Zeunert, Patrick Renner, Philipp Dresselhaus, Sebastian Meyer zu Borgsen, 
 * Soufian Jebbara, Tobias Röhlig, Torben Toeniges, Viktor Losing, Viktor Richter
 * %LICENSE#
 */

import de.unibi.airobots.btl.List;
import de.unibi.airobots.btl.Type;
import de.unibi.airobots.btl.data.navigation.PositionData;
import de.unibi.airobots.btl.units.AngleUnit;
import de.unibi.airobots.btl.units.LengthUnit;
import de.unibi.citec.clf.bonsai.core.CommunicationException;
import de.unibi.citec.clf.bonsai.core.CoreObjectFactory.CoreObjectCreationException;
import de.unibi.citec.clf.bonsai.core.MemorySlot;
import de.unibi.citec.clf.bonsai.xcf.configuration.ConfiguredXcfAmWorkingMemorySlot;
import java.util.HashSet;
import java.util.Set;
import net.sf.xcf.event.MemoryEvent;
import net.sf.xcf.jam.ActiveMemoryRAM;
import net.sf.xcf.jam.EventDispatcher;
import net.sf.xcf.memory.MemoryException;
import net.sf.xcf.transport.XOPData;
import net.sf.xcf.util.SynchronizedQueue;
import net.sf.xcf.xml.XPath;
import org.apache.log4j.BasicConfigurator;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

public class AmWorkingMemoryTest {

    private static final String MEMORY_NAME = "testam";
    private static final String SLOT_NAME = "testslot";
    private ActiveMemoryRAM memory;
    Set<ConfiguredXcfAmWorkingMemorySlot> slots = new HashSet<ConfiguredXcfAmWorkingMemorySlot>();

    /**
     * Static initializer for logging.
     */
    @BeforeClass
    public static void setUpLogging() {
        BasicConfigurator.configure();
    }

    @Before
    public void setUp() throws Exception {
        EventDispatcher dummyDispatcher = new EventDispatcher() {
            public void fireEvent(MemoryEvent event) {
                // do nothing
            }
        };
        memory = new ActiveMemoryRAM(MEMORY_NAME, dummyDispatcher);

        Class<?> dataType = Type.class;
        Class<? extends MemorySlot<?>> slotClass = (Class<? extends MemorySlot<?>>) AmBtlMemorySlot.class;
        ConfiguredXcfAmWorkingMemorySlot slot0 = new ConfiguredXcfAmWorkingMemorySlot(
                dataType, slotClass);
        slots.add(slot0);

    }

    @Test
    public void testSlotCreationAndFunction() throws IllegalArgumentException,
            CoreObjectCreationException, CommunicationException,
            InterruptedException, MemoryException {

        AmWorkingMemory wm = new AmWorkingMemory(MEMORY_NAME, slots);
        wm.resetActiveMemory(memory);

        MemorySlot<PositionData> slot = wm.getSlot(SLOT_NAME,
                PositionData.class);

        PositionData pos = new PositionData(1.0, 2.0, 3.0, 1234,
                LengthUnit.METER, AngleUnit.RADIAN);

        SynchronizedQueue<XOPData> data = memory.query(new XPath("/"));
        assertFalse(data.hasNext());

        assertNull(slot.recall());

        slot.memorize(pos);

        data = memory.query(new XPath("/"));
        assertTrue(data.hasNext());

        PositionData recalled = slot.recall();

        assertEquals(pos, recalled);

        slot.forget();

        assertNull(slot.recall());

    }

    @Test
    public void testListSlot() throws IllegalArgumentException,
            CoreObjectCreationException, CommunicationException,
            InterruptedException, MemoryException {

        AmWorkingMemory wm = new AmWorkingMemory(MEMORY_NAME, slots);
        wm.resetActiveMemory(memory);

        Class<List<PositionData>> listType = (Class<List<PositionData>>) List.getListClass(PositionData.class);
        MemorySlot<List<PositionData>> slot = wm.getSlot(SLOT_NAME,
                listType);

        PositionData pos = new PositionData(1.0, 2.0, 3.0, 1234,
                LengthUnit.METER, AngleUnit.RADIAN);
        List<PositionData> list = new List<PositionData>(PositionData.class);
        list.add(pos);

        SynchronizedQueue<XOPData> data = memory.query(new XPath("/"));
        assertFalse(data.hasNext());

        assertNull(slot.recall());

        slot.memorize(list);

        data = memory.query(new XPath("/"));
        assertTrue(data.hasNext());

        List<PositionData> recalled = slot.recall();

        assertEquals(list, recalled);

        slot.forget();

        assertNull(slot.recall());

    }

    @Test(expected = CoreObjectCreationException.class)
    public void testUnsupportedDataType() throws IllegalArgumentException,
            CoreObjectCreationException, CommunicationException {

        AmWorkingMemory wm = new AmWorkingMemory(MEMORY_NAME, slots);
        wm.resetActiveMemory(memory);
        MemorySlot<String> slot1 = wm.getSlot(SLOT_NAME, String.class);
        slot1.forget();
    }
}
